@@ -25,32 +25,29 @@ class GetAlipayUrlRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'GetAlipayUrl')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OrderId(self):
+	def get_OrderId(self): # Long
 		return self.get_query_params().get('OrderId')
 
-	def set_OrderId(self,OrderId):
-		self.add_query_param('OrderId',OrderId)
-
-	def get_Type(self):
+	def set_OrderId(self, OrderId):  # Long
+		self.add_query_param('OrderId', OrderId)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_BizType(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_BizType(self): # String
 		return self.get_query_params().get('BizType')
 
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
-
-	def get_ReturnUrl(self):
+	def set_BizType(self, BizType):  # String
+		self.add_query_param('BizType', BizType)
+	def get_ReturnUrl(self): # String
 		return self.get_query_params().get('ReturnUrl')
 
-	def set_ReturnUrl(self,ReturnUrl):
-		self.add_query_param('ReturnUrl',ReturnUrl)
\ No newline at end of file
+	def set_ReturnUrl(self, ReturnUrl):  # String
+		self.add_query_param('ReturnUrl', ReturnUrl)
