@@ -25,32 +25,29 @@ class OperateProduceForPartnerRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'OperateProduceForPartner')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BizType(self):
+	def get_BizType(self): # String
 		return self.get_query_params().get('BizType')
 
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
-
-	def get_ExtInfo(self):
+	def set_BizType(self, BizType):  # String
+		self.add_query_param('BizType', BizType)
+	def get_ExtInfo(self): # String
 		return self.get_query_params().get('ExtInfo')
 
-	def set_ExtInfo(self,ExtInfo):
-		self.add_query_param('ExtInfo',ExtInfo)
-
-	def get_BizId(self):
+	def set_ExtInfo(self, ExtInfo):  # String
+		self.add_query_param('ExtInfo', ExtInfo)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
-
-	def get_OperateType(self):
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
+	def get_OperateType(self): # String
 		return self.get_query_params().get('OperateType')
 
-	def set_OperateType(self,OperateType):
-		self.add_query_param('OperateType',OperateType)
\ No newline at end of file
+	def set_OperateType(self, OperateType):  # String
+		self.add_query_param('OperateType', OperateType)
