@@ -25,26 +25,24 @@ class RejectUserSolutionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'RejectUserSolution')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BizType(self):
+	def get_BizType(self): # String
 		return self.get_query_params().get('BizType')
 
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
-
-	def get_Note(self):
+	def set_BizType(self, BizType):  # String
+		self.add_query_param('BizType', BizType)
+	def get_Note(self): # String
 		return self.get_query_params().get('Note')
 
-	def set_Note(self,Note):
-		self.add_query_param('Note',Note)
-
-	def get_SolutionBizId(self):
+	def set_Note(self, Note):  # String
+		self.add_query_param('Note', Note)
+	def get_SolutionBizId(self): # String
 		return self.get_query_params().get('SolutionBizId')
 
-	def set_SolutionBizId(self,SolutionBizId):
-		self.add_query_param('SolutionBizId',SolutionBizId)
\ No newline at end of file
+	def set_SolutionBizId(self, SolutionBizId):  # String
+		self.add_query_param('SolutionBizId', SolutionBizId)
