@@ -25,26 +25,24 @@ class ReleaseProduceAuthorizationRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'ReleaseProduceAuthorization')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BizType(self):
+	def get_BizType(self): # String
 		return self.get_body_params().get('BizType')
 
-	def set_BizType(self,BizType):
+	def set_BizType(self, BizType):  # String
 		self.add_body_params('BizType', BizType)
-
-	def get_AuthorizedUserId(self):
+	def get_AuthorizedUserId(self): # String
 		return self.get_body_params().get('AuthorizedUserId')
 
-	def set_AuthorizedUserId(self,AuthorizedUserId):
+	def set_AuthorizedUserId(self, AuthorizedUserId):  # String
 		self.add_body_params('AuthorizedUserId', AuthorizedUserId)
-
-	def get_BizId(self):
+	def get_BizId(self): # String
 		return self.get_body_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_body_params('BizId', BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_body_params('BizId', BizId)
